@@ -7,8 +7,6 @@ from enum import Enum
 from string import Template
 from typing import TYPE_CHECKING, Any, List, Mapping, Optional, Union
 
-from robotcode.core.dataclasses import as_dict, from_dict
-from robotcode.core.logging import LoggingDescriptor
 from robotcode.core.lsp.types import (
     AnnotatedTextEdit,
     ChangeAnnotation,
@@ -25,7 +23,9 @@ from robotcode.core.lsp.types import (
     TextEdit,
     WorkspaceEdit,
 )
+from robotcode.core.utils.dataclasses import as_dict, from_dict
 from robotcode.core.utils.inspect import iter_methods
+from robotcode.core.utils.logging import LoggingDescriptor
 from robotcode.robot.utils import get_robot_version
 
 from ...common.decorators import code_action_kinds, language_id
@@ -133,7 +133,7 @@ class RobotCodeActionRefactorProtocolPart(RobotLanguageServerProtocolPart, Model
 
     def get_valid_nodes_in_range(self, model: ast.AST, range: Range, also_return: bool = False) -> List[ast.AST]:
         from robot.parsing.lexer.tokens import Token as RobotToken
-        from robot.parsing.model.blocks import Block, Keyword, TestCase, Try
+        from robot.parsing.model.blocks import Block, Keyword, TestCase
         from robot.parsing.model.statements import (
             Comment,
             Documentation,
@@ -141,8 +141,6 @@ class RobotCodeActionRefactorProtocolPart(RobotLanguageServerProtocolPart, Model
             ElseIfHeader,
             EmptyLine,
             End,
-            ExceptHeader,
-            FinallyHeader,
             Fixture,
             ForHeader,
             IfHeader,
@@ -151,12 +149,19 @@ class RobotCodeActionRefactorProtocolPart(RobotLanguageServerProtocolPart, Model
             SingleValue,
             TemplateArguments,
             TestCaseName,
-            TryHeader,
-            WhileHeader,
         )
 
         if get_robot_version() >= (5, 0, 0):
-            from robot.parsing.model.statements import Break, Continue, ReturnStatement
+            from robot.parsing.model.blocks import Try
+            from robot.parsing.model.statements import (
+                Break,
+                Continue,
+                ExceptHeader,
+                FinallyHeader,
+                ReturnStatement,
+                TryHeader,
+                WhileHeader,
+            )
 
         if not isinstance(model, (Keyword, TestCase)):
             return []
@@ -206,6 +211,7 @@ class RobotCodeActionRefactorProtocolPart(RobotLanguageServerProtocolPart, Model
                 return []
 
         results = []
+
         for block in [model, *blocks]:
             sub = [n for n in result if n in ast_utils.iter_nodes(block, False)]
             if sub:
@@ -228,12 +234,10 @@ class RobotCodeActionRefactorProtocolPart(RobotLanguageServerProtocolPart, Model
                     ElseHeader,
                     ForHeader,
                     End,
-                    TryHeader,
-                    ExceptHeader,
-                    FinallyHeader,
-                    WhileHeader,
                 ),
             )
+            or get_robot_version() >= (5, 0)
+            and isinstance(n, (WhileHeader, TryHeader, ExceptHeader, FinallyHeader))
         ):
             return []
 
@@ -323,7 +327,7 @@ class RobotCodeActionRefactorProtocolPart(RobotLanguageServerProtocolPart, Model
         if not insert_range:
             return None
 
-        document = await self.parent.documents.get(data.document_uri)
+        document = self.parent.documents.get(data.document_uri)
         if document is None:
             return None
 
@@ -449,7 +453,7 @@ class RobotCodeActionRefactorProtocolPart(RobotLanguageServerProtocolPart, Model
         if range.start.line != range.end.line:
             return None
 
-        document = await self.parent.documents.get(document_uri)
+        document = self.parent.documents.get(document_uri)
         if document is None:
             return None
 
@@ -546,7 +550,7 @@ class RobotCodeActionRefactorProtocolPart(RobotLanguageServerProtocolPart, Model
     ) -> Optional[CodeAction]:
         from robot.parsing.model.blocks import Keyword, TestCase
 
-        document = await self.parent.documents.get(data.document_uri)
+        document = self.parent.documents.get(data.document_uri)
         if document is None:
             return None
 
